<?php
/**
 * MyResearch Controller
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2010.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Controller
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
namespace fid_bbi\Controller;

use fid\Service\ClientException;
use fid\Service\DataTransferObject\Library;
use VuFind\Exception\Forbidden;
use Zend\ServiceManager\ServiceLocatorInterface;

/**
 * Controller for the user account area.
 *
 * @category VuFind
 * @package  Controller
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
class MyResearchController extends \fid\Controller\MyResearchController
{
    public function usertagsAction() {

        // Not logged in?  Force user to log in:
        if (!$this->getAuthManager()->isLoggedIn()) {
            // Allow bypassing of post-login redirect
            if ($this->params()->fromQuery('redirect', true)) {
                $this->setFollowupUrlToReferer();
            }
            return $this->forwardTo('MyResearch', 'Login');
        }
        $user = $this->getUser();
        $tags = [];
        if ($user) {
            $tags =
                $this->serviceLocator->get('VuFind\Db\Table\PluginManager')
                ->get('tags')
                ->getAllForUser($user->id);
            $lists = [];
            foreach ($user->getLists() as $list) {
                $lists[$list->id] = [
                    'id' => $list->id,
                    'title' => $list->title,
                ];
            }
        }
        return $this->createViewModel(compact('lists','tags'));
    }


    /**
     * Check if licenses are specified
     * overrides parent function avoiding authentication
     *
     * @return bool
     */
    public function hasLicenses(): bool
    {
        // Are licenses configured
        if (!isset($this->mainConfig['MediaLicenses']) || count($this->mainConfig['MediaLicenses']) == 0) {
            return false;
        }

        return true;
    }
}
